package com.ruoyi.invest.service;

import java.util.List;
import com.ruoyi.invest.domain.AccountsDealRecord;
import com.ruoyi.invest.domain.dto.AccountsDealRecordDto;
import com.ruoyi.invest.domain.vo.AccountsDealRecordVo;

/**
 * 账户交易记录Service接口
 *
 * @author tianyongbao
 * @date 2024-03-30
 */
public interface IAccountsDealRecordService
{
    /**
     * 查询账户交易记录
     *
     * @param id 账户交易记录主键
     * @return 账户交易记录
     */
    public AccountsDealRecordVo selectAccountsDealRecordById(Long id);

    /**
     * 查询账户交易记录列表
     *
     * @param accountsDealRecordDto 账户交易记录
     * @return 账户交易记录集合
     */
    public List<AccountsDealRecordVo> selectAccountsDealRecordList(AccountsDealRecordDto accountsDealRecordDto);

    /**
     * 新增账户交易记录
     *
     * @param accountsDealRecord 账户交易记录
     * @return 结果
     */
    public int insertAccountsDealRecord(AccountsDealRecord accountsDealRecord);

    /**
     * 修改账户交易记录
     *
     * @param accountsDealRecord 账户交易记录
     * @return 结果
     */
    public int updateAccountsDealRecord(AccountsDealRecord accountsDealRecord);

    /**
     * 批量删除账户交易记录
     *
     * @param ids 需要删除的账户交易记录主键集合
     * @return 结果
     */
    public int deleteAccountsDealRecordByIds(Long[] ids);

    /**
     * 删除账户交易记录信息
     *
     * @param id 账户交易记录主键
     * @return 结果
     */
    public int deleteAccountsDealRecordById(Long id);
}
